"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
class Reporter {
    constructor() {
        this.result = {};
    }
    add(node, rule, message, context) {
        if (!this.result.hasOwnProperty(context.filename)) {
            this.result[context.filename] = [];
        }
        this.result[context.filename].push({
            ruleId: rule.name,
            severity: config_1.default.SEVERITY_ERROR,
            message,
            line: context.line,
            column: context.column,
        });
    }
    addManual(filename, message) {
        if (!this.result.hasOwnProperty(filename)) {
            this.result[filename] = [];
        }
        this.result[filename].push(message);
    }
    save() {
        return {
            valid: Object.keys(this.result).length === 0,
            results: Object.keys(this.result).map(filePath => {
                const messages = this.result[filePath];
                return {
                    filePath,
                    messages,
                    errorCount: messages.filter(m => m.severity === config_1.default.SEVERITY_ERROR).length,
                    warningCount: messages.filter(m => m.severity === config_1.default.SEVERITY_WARN).length,
                };
            }),
        };
    }
}
exports.Reporter = Reporter;
exports.default = Reporter;
